#Productiemodel 

#Berekent gemiddelde productie per uur van benthische algen in bovenste 2mm van het sediment 
#Gebruikte productiemodel: EP
#Aangepast aan de hand van Forster et al. 2006

#Benodigde input:
# - externe lichtintensiteit (uurgemiddeldes)
# - droogval wel/ niet (1/0) per uur van locatie over een bepaalde tijdsperiode. het eerste uur dat het sediment droogvalt moet ook beschouwd worden als niet droog (opwaartse migratie algen vindt plaats)
# - chlorofyl-a concentraties in bovenste 2 mm van het sediment
# - mud content (fractie < 63 um)
# - photosyntheseparameters alpha en pmax

#Initialisatie --------------------------------------------------------------------------------------------------------------------------------------------------------

require(plyr)

#set working directory
setwd("//ZEUS/eds/users/tisjad/Grazing_campaign_2015/RData")

#Load chlorophyll-a concentration data in mg/m2 (sampled from upper 1 cm of the sediment)
chla <- read.csv("//zeus/eds/users/tisjad/Grazing_campaign_2015/Datasets/Sampling_campaign_march/Sediment_samples/slib_chla_03042015.csv")

#make column with plot names
chla$plotnr <- substr(chla$Customer.Code,1,3)

#convert plot names to capital letters
chla$plotnr <- sapply(chla$plotnr, toupper)

#load mud content data (%)
slib <- read.csv("//zeus/eds/users/tisjad/Grazing_campaign_2015/Datasets/Sampling_campaign_march/Sediment_samples/slib_chla_03042015_methooglaag.csv")

#Load photosynthetic parameters measured with the PAM in ??mol photon m???2 s???1
EP_pars0304_sort <- read.csv("//zeus/eds/users/tisjad/PP_Campaign_2014/PP_model_RS/PAM_data_Ft150/EP_pars0304_allplots.csv")

#Add column to dataset with information on estuary (oosterschelde/ westerschelde)
Estuary <- c(rep("Eastern Scheldt",18),rep("Western Scheldt",72),rep("Eastern Scheldt",18),rep("Western Scheldt",18),rep("Eastern Scheldt",18),rep("Western Scheldt",18))
Estuary2 <- c(rep("Eastern Scheldt",6),rep("Western Scheldt",24),rep("Eastern Scheldt",6),rep("Western Scheldt",6),rep("Eastern Scheldt",6),rep("Western Scheldt",6))
EP_pars0304_sort$Estuary <- Estuary
slib$Estuary <- Estuary

#split dataset into separate dataset per estuary
EP_pars0304_sort_OOS <- EP_pars0304_sort[EP_pars0304_sort$Estuary == "Eastern Scheldt",]
EP_pars0304_sort_WES <- EP_pars0304_sort[EP_pars0304_sort$Estuary == "Western Scheldt",]

slib_OOS <- slib[slib$Estuary == "Eastern Scheldt",]
slib_WES <- slib[slib$Estuary == "Western Scheldt",]

#load LIGHT INTENSITY ABOVE THE SEDIMENT ALSO DURING IMMERSION (CALCULATED USING KD OF WATER COLUMN) in ??mol photon m???2 s???1)
#a value is hoven for every 10 min
load("//ZEUS/eds/users/tisjad/PP_Campaign_2014/PP_model_RS/Rscripts/Tide_estimation_model/PAR_bottom_hour.RData")


require(plyr)
#calculate average chl-a concentration per plot (from 3 replicate samples)
Chla <- ddply(chla,~plotnr,summarise,mean=mean(Chla_m2),sd=sd(Chla_m2))

#add estuary information
Chla$Estuary <- Estuary2

#split dataset into separate set for the Oosterschelde and Westerschelde
Chla_OOS <- Chla[Chla$Estuary == "Eastern Scheldt",]
Chla_WES <- Chla[Chla$Estuary == "Western Scheldt",]

#replicate each value 3 times, because we calculate production with three PAM values per plot
Chla_OOS <- rep(Chla_OOS$mean,each=3)
Chla_WES <- rep(Chla_WES$mean,each=3)

#calculate average mud content per plot (from 3 replicate samples)
slib_OOS$plotnr <- substr(slib_OOS$Customer.Code,1,3)
slib_WES$plotnr <- substr(slib_WES$Customer.Code,1,3)
slib_OOS_average <- ddply(slib_OOS,~plotnr,summarise,mean=mean(SSILT63_2....),sd=sd(SSILT63_2....))
slib_WES_average <- ddply(slib_WES,~plotnr,summarise,mean=mean(SSILT63_2....),sd=sd(SSILT63_2....))

mud_OOS <- rep(slib_OOS_average$mean,each=3)
mud_WES <- rep(slib_WES_average$mean,each=3)


#Put input data in the right format-------------------------------------------------------------------------------------------------------------------------------------------

#The production of microphytobenthos is calculculated per vertical layer of 0.01 mm. A light attenuation coefficient is calculated from the chl-a concentration
#using a linear regression formula.
z <- seq(0,1.99,0.01)
z2 <- seq(0,2,0.01)#depth in mm

#Get kd based on mud content and average chl-a concentration (based on linear regression Kd data from Eden estuary (Jacco Kromkamp))
Kd_station_OOS <- -3.1167 + 1.8298*log(Chla_OOS)
Kd_station_WES <- -3.1167 + 1.8298*log(Chla_WES)

#Photosynthetic parameters are converted to numeric (instead of 'factor')
ps_OOS <- as.numeric(as.character(EP_pars0304_sort_OOS$ps))
alpha_OOS <- as.numeric(as.character(EP_pars0304_sort_OOS$alpha))
eopt_OOS <- as.numeric(as.character(EP_pars0304_sort_OOS$eopt))

ps_WES <- as.numeric(as.character(EP_pars0304_sort_WES$ps))
alpha_WES <- as.numeric(as.character(EP_pars0304_sort_WES$alpha))
eopt_WES <- as.numeric(as.character(EP_pars0304_sort_WES$eopt))


# calculate respiration rate by multiplying pmax with 0.05 (5% OF pS). Respiration is now expressed as ??mol photon m???2 s???1, but is converted to mg C mg???1 chla h???1 in the production formula
#res_par <- 0.05  
res_par <- 0.015  
RES_OOS <- res_par*ps_OOS  
RES_WES <- res_par*ps_WES


#---------------------------------------------------------------------------------------------------------------------------------------------------------------------------

##### -----     PP model     ----- ######-----------------------------------------------------------------------------------------------------------------------------------

#create separate variable with time series of PAR for plots of the oosterschelde and westerschelde

PAR_bottom_hour_OOS <- PAR_bottom_hour[,substr(colnames(PAR_bottom_hour),1,2) == "DO" | substr(colnames(PAR_bottom_hour),1,2) == "RA" | substr(colnames(PAR_bottom_hour),1,2) == "VI"]
PAR_bottom_hour_WES <- PAR_bottom_hour[,substr(colnames(PAR_bottom_hour),1,2) == "HE" | substr(colnames(PAR_bottom_hour),1,2) == "MI" | substr(colnames(PAR_bottom_hour),1,2) == "MO" | substr(colnames(PAR_bottom_hour),1,2) == "PA" | substr(colnames(PAR_bottom_hour),1,2) == "RI" | substr(colnames(PAR_bottom_hour),1,2) == "WA"]

PAR_bottom_hour_OOS <- PAR_bottom_hour_OOS[ , order(names(PAR_bottom_hour_OOS))]
PAR_bottom_hour_WES <- PAR_bottom_hour_WES[ , order(names(PAR_bottom_hour_WES))]

#multiply columns by three as we have three replicate PAM values of each plot
PAR_bottom_hour_OOS_rep <- PAR_bottom_hour_OOS[,rep(1:ncol(PAR_bottom_hour_OOS),each=3)]
PAR_bottom_hour_WES_rep <- PAR_bottom_hour_WES[,rep(1:ncol(PAR_bottom_hour_WES),each=3)]


#Make a list containing a matrix of PAR information over time for each plot. A matrix with 200 values (as we have 
#200 depth layers) at each time step. The matrix created now contains PAR values at the sediment surface in each vertical layer
#in line 265 those values are converted to the correct values at each specific depth using the formula:  ID = I0 * e^(-kD) 
light_rep_mat_OOS <- list()
light_rep_mat_WES <- list()

for (d in 1:ncol(PAR_bottom_hour_OOS_rep)){
  
  light_mat <- t(as.matrix(PAR_bottom_hour_OOS_rep[,d]))
  light_mat <- t(as.matrix(sapply(light_mat, as.numeric)))
  light_mat[light_mat < 0 ] <- 0
  
  light_rep_mat_OOS[[d]] <- light_mat[rep(1, 200),]
  
  
}

for (d in 1:ncol(PAR_bottom_hour_WES_rep)){
  
  light_mat <- t(as.matrix(PAR_bottom_hour_WES_rep[,d]))
  light_mat <- t(as.matrix(sapply(light_mat, as.numeric)))
  light_mat[light_mat < 0 ] <- 0
  
  light_rep_mat_WES[[d]] <- light_mat[rep(1, 200),]
  
  
}

#Calculate vertical distribution of chlorophyll-a within the sediment in the upper 2 mm. Although chl-a was sampled up to a depth of 1 cm, we assume 
#here that 100% of this chlorophyll-a is present in the upper 2 mm

dmax <- 1.99 #maximum sediment depth in mm (1.99-2 mm is the deepest layer)
mud_OOS <- 0.01 * mud_OOS #percentage of < 63 m particles in sample / 100, to get a proportion of silt (matching the method of Jesus et al. 2006:
#Chla (cumulative)=(d/dmax) + proportion_mud * (1-d/dmax-e^(2ed/dmax))
mud_WES <- 0.01 * mud_WES
e <- 2.718281


#CALCULATE RELATIVE CUMULATIVE CHL-A PER VERTICAL LAYER

#OOS
mud_mat <- t(as.matrix(mud_OOS))
mud_rep_mat <- mud_mat[rep(1, 201),]
z2_mat <- as.matrix(z2)
z2_rep_mat <- z2_mat[,rep(1, length(mud_OOS))]
dmax2 <- 2

#formula of Jesus et al. is applied: #Chla(cumulative)=d/dmax+mud(1-d/dmax-e^2ed/dmax)
#chla (cumulative) = accumulated proportion of chl-a in each vertical layer
#d = depth in mm
#dmax = maximum depth (=2 mm)
#mud = proportion of fine particles (silt)
#e = 2.718281
all_chla <- z2_rep_mat/dmax2 + mud_rep_mat*(1-z2_rep_mat/dmax2-exp((-2*e*z2_rep_mat)/dmax2))
#the variable all_chla now represents the cumulative proportion of chla in each vertical layer

rm(z2_rep_mat,mud_rep_mat,z2_mat,mud_mat)

#CALCULATE RELATIVE proportion of CHL-A PER LAYER (NON-CUMULATIVE)
all_relative_chla <- all_chla[2:nrow(all_chla),] - all_chla[1:(nrow(all_chla)-1),]


## convert relative chla distribution in the vertical dimension to absolute chla concentrations, by multiplying 
#the relative proportion of chl-a in each vertical layer with the total chl-a concentration measured in the upper 1 cm

#create new variable
all_absolute_chla<-  data.frame(matrix(ncol = 0, nrow = 200))

#convert total chla in m
Chla_mat <- t(as.matrix(Chla_OOS))
Chla_rep_mat <- Chla_mat[rep(1, 200),]
rel_chla_sum <- colSums(all_relative_chla)
rel_chla_sum_mat<- t(as.matrix(rel_chla_sum))
sum_rep_mat <- rel_chla_sum_mat[rep(1, 200),]
Chla_rep <- Chla_mat[rep(1, 200),]

all_absolute_chla_OOS <- all_relative_chla*Chla_rep/sum_rep_mat

rm(Chla_mat,Chla_rep_mat,rel_chla_sum,rel_chla_sum_mat,sum_rep_mat,Chla_rep,all_relative_chla,all_chla)

#WES

mud_mat <- t(as.matrix(mud_WES))
mud_rep_mat <- mud_mat[rep(1, 201),]
z2_mat <- as.matrix(z2)
z2_rep_mat <- z2_mat[,rep(1, length(mud_WES))]
dmax2 <- 2

all_chla <- z2_rep_mat/dmax2 + mud_rep_mat*(1-z2_rep_mat/dmax2-exp((-2*e*z2_rep_mat)/dmax2))

rm(z2_rep_mat,mud_rep_mat,mud_mat)

#CALCULATE RELATIVE CHL-A CONCENTRATION PER LAYER (SO NON-CUMULATIVE)
all_relative_chla <- all_chla[2:nrow(all_chla),] - all_chla[1:(nrow(all_chla)-1),]

plot(z2_mat[1:200],all_relative_chla[,50])

sum(all_relative_chla[1:100,50])

## relative to absolute chla distribution
all_absolute_chla<-  data.frame(matrix(ncol = 0, nrow = 200))
#for (zz in 1: length(all_relative_chla)){
#for (zz in 1: 10){
#absolute_chla <- all_relative_chla[,zz] * Chla[zz] / sum(all_relative_chla[,zz])

# all_absolute_chla <- cbind(all_absolute_chla,absolute_chla)}

Chla_mat <- t(as.matrix(Chla_WES))
Chla_rep_mat <- Chla_mat[rep(1, 200),]
rel_chla_sum <- colSums(all_relative_chla)
rel_chla_sum_mat<- t(as.matrix(rel_chla_sum))
sum_rep_mat <- rel_chla_sum_mat[rep(1, 200),]
Chla_rep <- Chla_mat[rep(1, 200),]

all_absolute_chla_WES <- all_relative_chla*Chla_rep/sum_rep_mat

rm(Chla_mat,Chla_rep_mat,rel_chla_sum,rel_chla_sum_mat,sum_rep_mat,Chla_rep,all_relative_chla,all_chla)



########CALCULATE PRODUCTION USING EP FORMULATION----------------------------------------------------------------------

#plots with no fluorescence are assumed to have a production rate of 0
alpha_OOS[is.na(alpha_OOS)] <- 0
eopt_OOS[is.na(eopt_OOS)] <- 0
ps_OOS[is.na(ps_OOS)] <- 0

alpha_WES[is.na(alpha_WES)] <- 0
eopt_WES[is.na(eopt_WES)] <- 0
ps_WES[is.na(ps_WES)] <- 0

RES_OOS[is.na(RES_OOS)] <- 0
RES_WES[is.na(RES_WES)] <- 0



#Calculate production OOS - GRAZING PAPER

#Production is calculated per plot

#create empty matrix
P_pixels_OOS <- matrix(nrow=0,ncol=1)

#production is caluclated in a loop, one calculation for each PAM value (3 per plot)
for (kk in 1:length(alpha_OOS)){  
  
  #Calculate light intensity in each vertical layer using the follwing formula: ID = I0 * e^(-kD) 
  Ez <- light_rep_mat_OOS[[kk]]*exp(-Kd_station_OOS[kk]*z) 
  
  #retrieve the vertical chla distribution of 1 plot
  chla <- as.matrix(all_absolute_chla_OOS[,kk])
  
  #replicate the vertical distribution for all time steps (march -april every 10 min)
  chla_rep_mat <- chla[,rep(1, 4463)]
  
  #calculate production for each vertical layer and for each time step (using a matrix calculation) following the formula of Eilers and Peeters
  response <- Ez/((1/(alpha_OOS[kk]*eopt_OOS[kk]^2))*Ez^2+t((1/ps_OOS[kk]-2/(alpha_OOS[kk]*eopt_OOS[kk]))*t(Ez))+(1/alpha_OOS[kk]))*chla_rep_mat-(chla_rep_mat*RES_OOS[kk])
  
  #subtract the respiration rate and multiply with 0.043 to convert production rates to mg Cm???2 h???1
  #sum up all calculated production rates over time per plot
  response_sum <- (colSums(response)) *0.043
  PP_allpixels_time <- response_sum
  P_pixels_OOS <- rbind(P_pixels_OOS,sum(PP_allpixels_time))
  print(kk)
}

response[is.na(response)] <- 0
test <- colSums(response)
time <- seq(1,4463,1)

plot(time,response_sum)

#plots without PAM measurements are given an value of 0
P_pixels_OOS[is.na(P_pixels_OOS)] <- 0

slib_OOS$plotshort <- substr(slib_OOS$Customer.Code,1,3)

#add plot names
P_pixels_OOS_plot <- as.data.frame(cbind(P_pixels_OOS,slib_OOS$plotshort))
class(P_pixels_OOS_plot$V1)
P_pixels_OOS_plot$V1 <- as.numeric(as.character(P_pixels_OOS_plot$V1))
P_pixels_OOS_plot$V2 <- as.character(P_pixels_OOS_plot$V2)

#calculate average production per plot (from 3 replicate calculations)
OOS_production <- ddply(P_pixels_OOS_plot, ~V2,summarise,mean=mean(V1),sd=sd(V1))

RDX_OOS <- ddply(slib_OOS, ~plotshort,summarise,mean=mean(RD_X),sd=sd(RD_X))
RDY_OOS <- ddply(slib_OOS, ~plotshort,summarise,mean=mean(RD_Y),sd=sd(RD_Y))

Prod_OOS_coord <- cbind(OOS_production$mean,RDX_OOS$mean,RDY_OOS$mean)

#DELEN DOOR AANTAL UREN TOTALE REKENPERIODE

#!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
class(OOS_production$mean)
OOS_production$mean <- OOS_production$mean/6/744*24

#Calculate production WES

P_pixels_WES <- matrix(nrow=0,ncol=1)

for (kk in 1:length(alpha_WES)){  
  
  Ez <- light_rep_mat_WES[[kk]]*exp(-Kd_station_WES[kk]*z) 
  
  chla <- as.matrix(all_absolute_chla_WES[,kk])
  chla_rep_mat <- chla[,rep(1, 4463)]
  
  response <- Ez/((1/(alpha_WES[kk]*eopt_WES[kk]^2))*Ez^2+t((1/ps_WES[kk]-2/(alpha_WES[kk]*eopt_WES[kk]))*t(Ez))+(1/alpha_WES[kk]))*chla_rep_mat
  response_sum <- (colSums(response)-RES_WES[kk]) *0.043
  PP_allpixels_time <- response_sum
  P_pixels_WES <- rbind(P_pixels_WES,sum(PP_allpixels_time))
  print(kk)
}


#save(P_pixels_WES,P_pixels_OOS,EP_pars0304_sort_OOS,EP_pars0304_sort_WES, file="//ZEUS/eds/users/tisjad/Grazing_campaign_2015/Datasets/grazing_production_data_paperV4/production_with_PAR_submersed.RData")

#P_pixels_WES[is.na(P_pixels_WES)] <- 0

slib_WES$plotshort <- substr(slib_WES$Customer.Code,1,3)

P_pixels_WES_plot <- as.data.frame(cbind(P_pixels_WES,slib_WES$plotshort))

P_pixels_WES_plot$V1 <- as.numeric(as.character(P_pixels_WES_plot$V1))
P_pixels_WES_plot$V2 <- as.character(P_pixels_WES_plot$V2)

WES_production <- ddply(P_pixels_WES_plot, ~V2,summarise,mean=mean(V1),sd=sd(V1))

WES_production$mean[is.na(WES_production$mean)]<- 0

WES_production$mean <- WES_production$mean/744*24

RDX_WES <- ddply(slib_WES, ~plotshort,summarise,mean=mean(RD_X),sd=sd(RD_X))
RDY_WES <- ddply(slib_WES, ~plotshort,summarise,mean=mean(RD_Y),sd=sd(RD_Y))

Prod_WES_coord <- cbind(WES_production$mean,RDX_WES$mean,RDY_WES$mean)

Prod_total <- rbind(Prod_OOS_coord,Prod_WES_coord)
Prod_total <- Prod_total[-55,]
Prod_total <- data.frame(cbind(Prod_total,c(unique(P_pixels_OOS_plot$V2),unique(P_pixels_WES_plot$V2))))
#Prod_total <- cbind(rbind(P_pixels_OOS_plot$V1,P_pixels_WES_plot$V1),rbind(P_pixels_OOS_plot$V2,P_pixels_WES_plot$V2))
Prod_total$X1 <- as.numeric(as.character(Prod_total$X1))


write.table(Prod_total,file="//zeus/eds/users/tisjad/PP_Campaign_2014/PP_model_RS/Model_output/Production_plots_12031004_field_perday_correct.txt")

allplots <- rbind(RDX_OOS,RDX_WES)
save(WES_production,OOS_production,file="//ZEUS/eds/users/tisjad/Grazing_campaign_2015/Datasets/Sampling_campaign_may/Metingen_PAM/Production_fieldbased_march_incl_emersion_pmax_from_temp.RData")
save(Prod_total,allplots,file="//zeus/eds/users/tisjad/PP_Campaign_2014/PP_model_RS/Model_output/Production_plots_12031004_field_perhour_correctedtime.RData")
#Select plots that are suitable for validation - dry during Landsat image acquisition

plots <- colnames(emersion_plots)[-1]

values <- matrix(nrow=0,ncol=1)
for (e in 1:length(production_plots$Plot)){
  
  val <- good_plots[grep(substr(production_plots$Plot[e],1,3),plots,perl=TRUE, value=FALSE)]
  
  values <- rbind(values,val)  
}

validation_plots <- production_plots[values == 13,]

prod_plots_field<- production_plots
prod_plots_model <- rbind(prod1,prod2,prod3)

save(prod_plots_field,prod_plots_model,file="prod_model_field.RData")

Plot_mean <- substr(validation_plots$Plot,1,3)
validation_plots$plot_name <- Plot_mean

mean_production <- ddply(validation_plots,~plot_name,summarise,mean=mean(Production),sd=sd(Production))

boxplot(Production ~ Plot,data=production_plots)


mean_emersion <- colSums(emersion_WES)/720

slib_WES$site <- substr(slib_WES$Customer.Code,1,2)

slib_WES <- cbind(slib_WES,mean_emersion)

emersion_per_site <- ddply(slib_WES,~site,summarise,mean=mean(mean_emersion),sd=sd(mean_emersion))





















